@@ -83,6 +83,9 @@ INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 # 生成唯一ID错误。
 INTERNALERROR_GENERATEID = 'InternalError.GenerateId'
 
+# Pdf合成错误。
+INTERNALERROR_PDF = 'InternalError.Pdf'
+
 # 上传印章失败。
 INTERNALERROR_SEALUPLOAD = 'InternalError.SealUpload'
 
@@ -194,6 +197,9 @@ INVALIDPARAMETER_MENUSTATUS = 'InvalidParameter.MenuStatus'
 # 缺少必填参数的值。
 INVALIDPARAMETER_MISSINGREQUIREDPARAMETERVALUE = 'InvalidParameter.MissingRequiredParameterValue'
 
+# 手机号码不正确。
+INVALIDPARAMETER_MOBILE = 'InvalidParameter.Mobile'
+
 # 姓名不符合要求。
 INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 
@@ -359,6 +365,12 @@ OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermissi
 # 超出查询上限。
 OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'
 
+# 当前企业员工没有开通境外签署能力。
+OPERATIONDENIED_OVERSEAABILITYNOTOPEN = 'OperationDenied.OverseaAbilityNotOpen'
+
+# 出证计费额度不足。
+OPERATIONDENIED_PROVENOQUOTA = 'OperationDenied.ProveNoQuota'
+
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
@@ -389,6 +401,9 @@ RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'
 # 签署人信息不存在，请检查后重试。
 RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 
+# 合同组不存在。
+RESOURCENOTFOUND_FLOWGROUP = 'ResourceNotFound.FlowGroup'
+
 # 机构不存在。
 RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
 
@@ -419,6 +434,9 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 请升级到对应版本后即可使用该接口。
+UNAUTHORIZEDOPERATION_NOPERMISSIONFEATURE = 'UnauthorizedOperation.NoPermissionFeature'
+
 # 未授权下载权限。
 UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONDOWNLOAD = 'UnauthorizedOperation.UnauthorizedOperationDownload'
 
